#ifndef Sanker_h
#define Sanker_h 1

#include "Interfaces.h"
#include "AbstractConcepts.h"
#include "UniRndGen.h"

class Visitor;
class Posetilac;

// Klasa Sanker implementira IFlowSource;
// Sanker jer je izvor (piva) i nasledjuje RandomTimedFlowlElement 
// jer Scheduler treba da kontrolise tocenje piva 
class Sanker : public IFlowSource, public RandomTimedFlowElement
{
public:
	// Inicijalizacija promenljivih kao i inicijalizacija
	// generatora slucajnih brojeva (po tekstu zadatka, uniformni)
	Sanker (int NN, double TT) 
		: N(NN), T(TT), RandomTimedFlowElement(new UniformGenerator (0.9*T, 1.1*T))
	{
		// Niz od N posetilaca (Posetilac je klasa uradjena pod b) i c))
		pos = new Posetilac*[N];
		for (int i=0; i<N; i++)
		{
			pos[i] = 0;
		}
		// Pocinje se od posetioca sa rednim brojem 0
		trenutniBrPos = 0;
	}

	~Sanker ()
	{
		delete [] pos;
	}

	bool addPosetilac(Posetilac*);

	virtual void accept (Visitor* vis);

	virtual void notify (int ID);

	// Ukljucivanje Sankera (radi)
	inline void switchOn () { onOff = true; }

	// Iskljucivanje Sankera (ne radi)
	inline void switchOff () { onOff = false; }

	// Ispitivanje da li radi/ne radi
	inline bool isOn () { return onOff; }

protected:	
	int N;                 // max. broj posetilaca
	double T;              // srednje vreme izmedju dva tocenja piva
	int trenutniBrPos;     // redni broj trenutnog posetioca
	Posetilac **pos;       // dinamicki niz posetilaca
	bool onOff;            // flag koji kaze da li sanker radi ili ne
};

#endif
